# -*- coding: utf-8 -*-
from __future__ import unicode_literals

from django.db import models, migrations


class Migration(migrations.Migration):

    dependencies = [
        ('councilmatic_core', '0006_bill_subject'),
    ]

    operations = [
        migrations.AddField(
            model_name='post',
            name='division_ocd_id',
            field=models.CharField(max_length=255, default=''),
            preserve_default=False,
        ),
        migrations.AddField(
            model_name='post',
            name='shape',
            field=models.TextField(blank=True),
        ),
    ]



# -*- coding: utf-8 -*-
from __future__ import unicode_literals

from django.db import models, migrations


class Migration(migrations.Migration):

    dependencies = [
    ]

    operations = [
        migrations.CreateModel(
            name='Action',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, verbose_name='ID', serialize=False)),
                ('date', models.DateTimeField(default=None)),
                ('classification', models.CharField(max_length=100)),
                ('description', models.TextField(blank=True)),
                ('order', models.IntegerField()),
            ],
        ),
        migrations.CreateModel(
            name='ActionRelatedEntity',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, verbose_name='ID', serialize=False)),
                ('entity_type', models.CharField(max_length=100)),
                ('entity_name', models.CharField(max_length=255)),
                ('organization_ocd_id', models.CharField(max_length=100, blank=True)),
                ('person_ocd_id', models.CharField(max_length=100, blank=True)),
                ('action', models.ForeignKey(related_name='related_entities', to='councilmatic_core.Action')),
            ],
        ),
        migrations.CreateModel(
            name='AgendaItemBill',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, verbose_name='ID', serialize=False)),
                ('note', models.CharField(max_length=255)),
            ],
        ),
        migrations.CreateModel(
            name='Bill',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, verbose_name='ID', serialize=False)),
                ('ocd_id', models.CharField(max_length=100, unique=True)),
                ('description', models.TextField()),
                ('identifier', models.CharField(max_length=50)),
                ('bill_type', models.CharField(max_length=50)),
                ('classification', models.CharField(max_length=100)),
                ('date_created', models.DateTimeField(default=None)),
                ('date_updated', models.DateTimeField(null=True, default=None)),
                ('source_url', models.CharField(max_length=255)),
                ('source_note', models.CharField(max_length=255, blank=True)),
                ('full_text', models.TextField(blank=True)),
                ('abstract', models.TextField(blank=True)),
                ('last_action_date', models.DateTimeField(null=True, default=None)),
                ('slug', models.CharField(max_length=255, unique=True)),
            ],
        ),
        migrations.CreateModel(
            name='BillDocument',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, verbose_name='ID', serialize=False)),
                ('bill', models.ForeignKey(related_name='documents', to='councilmatic_core.Bill')),
            ],
        ),
        migrations.CreateModel(
            name='Document',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, verbose_name='ID', serialize=False)),
                ('note', models.TextField()),
                ('url', models.TextField()),
            ],
        ),
        migrations.CreateModel(
            name='Event',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, verbose_name='ID', serialize=False)),
                ('ocd_id', models.CharField(max_length=100, unique=True)),
                ('name', models.CharField(max_length=255)),
                ('description', models.TextField()),
                ('classification', models.CharField(max_length=100)),
                ('start_time', models.DateTimeField()),
                ('end_time', models.DateTimeField(null=True)),
                ('all_day', models.BooleanField(default=False)),
                ('status', models.CharField(max_length=100)),
                ('location_name', models.CharField(max_length=255)),
                ('location_url', models.CharField(max_length=255, blank=True)),
                ('source_url', models.CharField(max_length=255)),
                ('source_note', models.CharField(max_length=255, blank=True)),
                ('slug', models.CharField(max_length=255, unique=True)),
            ],
        ),
        migrations.CreateModel(
            name='EventAgendaItem',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, verbose_name='ID', serialize=False)),
                ('order', models.IntegerField()),
                ('description', models.TextField()),
                ('event', models.ForeignKey(related_name='agenda_items', to='councilmatic_core.Event')),
            ],
        ),
        migrations.CreateModel(
            name='EventDocument',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, verbose_name='ID', serialize=False)),
                ('document', models.ForeignKey(related_name='events', to='councilmatic_core.Document')),
                ('event', models.ForeignKey(related_name='documents', to='councilmatic_core.Event')),
            ],
        ),
        migrations.CreateModel(
            name='EventParticipant',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, verbose_name='ID', serialize=False)),
                ('note', models.TextField()),
                ('entity_name', models.CharField(max_length=255)),
                ('entity_type', models.CharField(max_length=100)),
                ('event', models.ForeignKey(related_name='participants', to='councilmatic_core.Event')),
            ],
        ),
        migrations.CreateModel(
            name='LegislativeSession',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, verbose_name='ID', serialize=False)),
                ('identifier', models.CharField(max_length=255)),
                ('jurisdiction_ocd_id', models.CharField(max_length=255)),
                ('name', models.CharField(max_length=255)),
            ],
        ),
        migrations.CreateModel(
            name='Membership',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, verbose_name='ID', serialize=False)),
                ('label', models.CharField(max_length=255, blank=True)),
                ('role', models.CharField(max_length=255, blank=True)),
                ('start_date', models.DateField(null=True, default=None)),
                ('end_date', models.DateField(null=True, default=None)),
            ],
        ),
        migrations.CreateModel(
            name='Organization',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, verbose_name='ID', serialize=False)),
                ('ocd_id', models.CharField(max_length=100, unique=True)),
                ('name', models.CharField(max_length=255)),
                ('classification', models.CharField(max_length=255, null=True)),
                ('source_url', models.CharField(max_length=255, blank=True)),
                ('slug', models.CharField(max_length=255, unique=True)),
                ('parent', models.ForeignKey(null=True, to='councilmatic_core.Organization', related_name='children')),
            ],
        ),
        migrations.CreateModel(
            name='Person',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, verbose_name='ID', serialize=False)),
                ('ocd_id', models.CharField(max_length=100, unique=True)),
                ('name', models.CharField(max_length=100)),
                ('headshot', models.CharField(max_length=255, blank=True)),
                ('source_url', models.CharField(max_length=255)),
                ('source_note', models.CharField(max_length=255, blank=True)),
                ('website_url', models.CharField(max_length=255, blank=True)),
                ('email', models.CharField(max_length=255, blank=True)),
                ('slug', models.CharField(max_length=255, unique=True)),
            ],
        ),
        migrations.CreateModel(
            name='Post',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, verbose_name='ID', serialize=False)),
                ('ocd_id', models.CharField(max_length=100, unique=True)),
                ('label', models.CharField(max_length=255)),
                ('role', models.CharField(max_length=255)),
                ('organization', models.ForeignKey(related_name='posts', to='councilmatic_core.Organization')),
            ],
        ),
        migrations.CreateModel(
            name='Sponsorship',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, verbose_name='ID', serialize=False)),
                ('classification', models.CharField(max_length=255)),
                ('is_primary', models.BooleanField(default=False)),
                ('bill', models.ForeignKey(related_name='sponsorships', to='councilmatic_core.Bill')),
                ('person', models.ForeignKey(related_name='sponsorships', to='councilmatic_core.Person')),
            ],
        ),
        migrations.AddField(
            model_name='membership',
            name='organization',
            field=models.ForeignKey(related_name='memberships', to='councilmatic_core.Organization'),
        ),
        migrations.AddField(
            model_name='membership',
            name='person',
            field=models.ForeignKey(related_name='memberships', to='councilmatic_core.Person'),
        ),
        migrations.AddField(
            model_name='membership',
            name='post',
            field=models.ForeignKey(null=True, to='councilmatic_core.Post', related_name='memberships'),
        ),
        migrations.AddField(
            model_name='billdocument',
            name='document',
            field=models.ForeignKey(related_name='bills', to='councilmatic_core.Document'),
        ),
        migrations.AddField(
            model_name='bill',
            name='from_organization',
            field=models.ForeignKey(null=True, to='councilmatic_core.Organization', related_name='bills'),
        ),
        migrations.AddField(
            model_name='bill',
            name='legislative_session',
            field=models.ForeignKey(null=True, to='councilmatic_core.LegislativeSession', related_name='bills'),
        ),
        migrations.AddField(
            model_name='agendaitembill',
            name='agenda_item',
            field=models.ForeignKey(related_name='related_bills', to='councilmatic_core.EventAgendaItem'),
        ),
        migrations.AddField(
            model_name='agendaitembill',
            name='bill',
            field=models.ForeignKey(related_name='related_agenda_items', to='councilmatic_core.Bill'),
        ),
        migrations.AddField(
            model_name='action',
            name='bill',
            field=models.ForeignKey(null=True, to='councilmatic_core.Bill', related_name='actions'),
        ),
        migrations.AddField(
            model_name='action',
            name='organization',
            field=models.ForeignKey(null=True, to='councilmatic_core.Organization', related_name='actions'),
        ),
    ]



from django.conf.urls import url
from . import views

urlpatterns = [
    url(r'^$', views.IndexView.as_view(), name='index'),
    url(r'^about/$', views.AboutView.as_view(), name='abouts'),
    url(r'^committees/$', views.CommitteesView.as_view(), name='committees'),
    url(r'^council-members/$', views.CouncilMembersView.as_view(), name='council_members'),
    url(r'^committee/(?P<slug>.*)/$', views.CommitteeDetailView.as_view(), name='committee_detail'),
    url(r'^legislation/(?P<slug>.*)/$', views.BillDetailView.as_view(), name='bill_detail'),
    url(r'^person/(?P<slug>.*)/$', views.PersonDetailView.as_view(), name='person'),
    url(r'^events/$', views.EventsView.as_view(), name='events'),
    url(r'^event/(?P<slug>.*)/$', views.EventDetailView.as_view(), name='event_detail'),
    url(r'^flush-cache/(.*)/$', views.flush, name='flush'),
    url(r'^pdfviewer/$', views.pdfviewer, name='pdfviewer'),
]


# -*- coding: utf-8 -*-
from __future__ import unicode_literals

from django.db import models, migrations


class Migration(migrations.Migration):

    dependencies = [
        ('councilmatic_core', '0007_auto_20151223_1150'),
    ]

    operations = [
        migrations.AddField(
            model_name='bill',
            name='ocr_full_text',
            field=models.TextField(blank=True),
        ),
    ]



# -*- coding: utf-8 -*-
from __future__ import unicode_literals

from django.db import models, migrations
from django.utils.timezone import utc
import datetime


class Migration(migrations.Migration):

    dependencies = [
        ('councilmatic_core', '0009_bill_updated_at'),
    ]

    operations = [
        migrations.AddField(
            model_name='action',
            name='updated_at',
            field=models.DateTimeField(auto_now=True, default=datetime.datetime(2016, 1, 20, 18, 46, 57, 767919, tzinfo=utc)),
            preserve_default=False,
        ),
        migrations.AddField(
            model_name='actionrelatedentity',
            name='updated_at',
            field=models.DateTimeField(auto_now=True, default=datetime.datetime(2016, 1, 20, 18, 47, 4, 415901, tzinfo=utc)),
            preserve_default=False,
        ),
        migrations.AddField(
            model_name='agendaitembill',
            name='updated_at',
            field=models.DateTimeField(auto_now=True, default=datetime.datetime(2016, 1, 20, 18, 47, 8, 919814, tzinfo=utc)),
            preserve_default=False,
        ),
        migrations.AddField(
            model_name='billdocument',
            name='updated_at',
            field=models.DateTimeField(auto_now=True, default=datetime.datetime(2016, 1, 20, 18, 47, 14, 71987, tzinfo=utc)),
            preserve_default=False,
        ),
        migrations.AddField(
            model_name='document',
            name='updated_at',
            field=models.DateTimeField(auto_now=True, default=datetime.datetime(2016, 1, 20, 18, 47, 18, 455922, tzinfo=utc)),
            preserve_default=False,
        ),
        migrations.AddField(
            model_name='event',
            name='updated_at',
            field=models.DateTimeField(auto_now=True, default=datetime.datetime(2016, 1, 20, 18, 47, 23, 135929, tzinfo=utc)),
            preserve_default=False,
        ),
        migrations.AddField(
            model_name='eventagendaitem',
            name='updated_at',
            field=models.DateTimeField(auto_now=True, default=datetime.datetime(2016, 1, 20, 18, 47, 27, 383947, tzinfo=utc)),
            preserve_default=False,
        ),
        migrations.AddField(
            model_name='eventdocument',
            name='updated_at',
            field=models.DateTimeField(auto_now=True, default=datetime.datetime(2016, 1, 20, 18, 47, 32, 151960, tzinfo=utc)),
            preserve_default=False,
        ),
        migrations.AddField(
            model_name='eventparticipant',
            name='updated_at',
            field=models.DateTimeField(auto_now=True, default=datetime.datetime(2016, 1, 20, 18, 47, 36, 336258, tzinfo=utc)),
            preserve_default=False,
        ),
        migrations.AddField(
            model_name='legislativesession',
            name='updated_at',
            field=models.DateTimeField(auto_now=True, default=datetime.datetime(2016, 1, 20, 18, 47, 42, 400193, tzinfo=utc)),
            preserve_default=False,
        ),
        migrations.AddField(
            model_name='membership',
            name='updated_at',
            field=models.DateTimeField(auto_now=True, default=datetime.datetime(2016, 1, 20, 18, 47, 46, 375945, tzinfo=utc)),
            preserve_default=False,
        ),
        migrations.AddField(
            model_name='organization',
            name='updated_at',
            field=models.DateTimeField(auto_now=True, default=datetime.datetime(2016, 1, 20, 18, 47, 50, 855978, tzinfo=utc)),
            preserve_default=False,
        ),
        migrations.AddField(
            model_name='person',
            name='updated_at',
            field=models.DateTimeField(auto_now=True, default=datetime.datetime(2016, 1, 20, 18, 47, 54, 823989, tzinfo=utc)),
            preserve_default=False,
        ),
        migrations.AddField(
            model_name='post',
            name='updated_at',
            field=models.DateTimeField(auto_now=True, default=datetime.datetime(2016, 1, 20, 18, 48, 1, 399994, tzinfo=utc)),
            preserve_default=False,
        ),
        migrations.AddField(
            model_name='sponsorship',
            name='updated_at',
            field=models.DateTimeField(auto_now=True, default=datetime.datetime(2016, 1, 20, 18, 48, 5, 392000, tzinfo=utc)),
            preserve_default=False,
        ),
    ]
